# autogenerated module
from typing import List, Optional, TYPE_CHECKING

from ._schema import dataclass, field, DictMixin

if TYPE_CHECKING:   # Fix for pycharm autocompletion https://youtrack.jetbrains.com/issue/PY-54560
    from dataclasses import dataclass, field

from . import meta_v1


@dataclass
class CertificateSigningRequest(DictMixin):
    r"""CertificateSigningRequest objects provide a mechanism to obtain x509
      certificates by submitting a certificate signing request, and having it
      asynchronously approved and issued.
      
      Kubelets use this API to obtain:
       1. client certificates to authenticate to kube-apiserver (with the
      "kubernetes.io/kube-apiserver-client-kubelet" signerName).
       2. serving certificates for TLS endpoints kube-apiserver can connect to
      securely (with the "kubernetes.io/kubelet-serving" signerName).
      
      This API can be used to request client certificates to authenticate to
      kube-apiserver (with the "kubernetes.io/kube-apiserver-client" signerName), or
      to obtain certificates from custom non-Kubernetes signers.

      **parameters**

      * **spec** ``CertificateSigningRequestSpec`` - spec contains the certificate request, and is immutable after creation. Only
        the request, signerName, expirationSeconds, and usages fields can be set on
        creation. Other fields are derived by Kubernetes and cannot be modified by
        users.
      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ObjectMeta]`` - 
      * **status** ``Optional[CertificateSigningRequestStatus]`` - status contains information about whether the request is approved or denied,
        and the certificate issued by the signer, or the failure condition indicating
        signer failure.
    """
    spec: 'CertificateSigningRequestSpec'
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ObjectMeta]' = None
    status: 'Optional[CertificateSigningRequestStatus]' = None


@dataclass
class CertificateSigningRequestCondition(DictMixin):
    r"""CertificateSigningRequestCondition describes a condition of a
      CertificateSigningRequest object

      **parameters**

      * **status** ``str`` - status of the condition, one of True, False, Unknown. Approved, Denied, and
        Failed conditions may not be "False" or "Unknown".
      * **type** ``str`` - type of the condition. Known conditions are "Approved", "Denied", and
        "Failed".
        An "Approved" condition is added via the /approval subresource, indicating the
        request was approved and should be issued by the signer.
        A "Denied" condition is added via the /approval subresource, indicating the
        request was denied and should not be issued by the signer.
        A "Failed" condition is added via the /status subresource, indicating the
        signer failed to issue the certificate.
        Approved and Denied conditions are mutually exclusive. Approved, Denied, and
        Failed conditions cannot be removed once added.
        Only one condition of a given type is allowed.
      * **lastTransitionTime** ``Optional[meta_v1.Time]`` - lastTransitionTime is the time the condition last transitioned from one status
        to another. If unset, when a new condition type is added or an existing
        condition's status is changed, the server defaults this to the current time.
      * **lastUpdateTime** ``Optional[meta_v1.Time]`` - lastUpdateTime is the time of the last update to this condition
      * **message** ``Optional[str]`` - message contains a human readable message with details about the request state
      * **reason** ``Optional[str]`` - reason indicates a brief reason for the request state
    """
    status: 'str'
    type: 'str'
    lastTransitionTime: 'Optional[meta_v1.Time]' = None
    lastUpdateTime: 'Optional[meta_v1.Time]' = None
    message: 'Optional[str]' = None
    reason: 'Optional[str]' = None


@dataclass
class CertificateSigningRequestList(DictMixin):
    r"""CertificateSigningRequestList is a collection of CertificateSigningRequest
      objects

      **parameters**

      * **items** ``List[CertificateSigningRequest]`` - items is a collection of CertificateSigningRequest objects
      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ListMeta]`` - 
    """
    items: 'List[CertificateSigningRequest]'
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ListMeta]' = None


@dataclass
class CertificateSigningRequestSpec(DictMixin):
    r"""CertificateSigningRequestSpec contains the certificate request.

      **parameters**

      * **request** ``str`` - request contains an x509 certificate signing request encoded in a "CERTIFICATE
        REQUEST" PEM block. When serialized as JSON or YAML, the data is additionally
        base64-encoded.
      * **signerName** ``str`` - signerName indicates the requested signer, and is a qualified name.
        List/watch requests for CertificateSigningRequests can filter on this field
        using a "spec.signerName=NAME" fieldSelector.
        Well-known Kubernetes signers are:
         1. "kubernetes.io/kube-apiserver-client": issues client certificates that can
        be used to authenticate to kube-apiserver.
          Requests for this signer are never auto-approved by kube-controller-manager,
        can be issued by the "csrsigning" controller in kube-controller-manager.
         2. "kubernetes.io/kube-apiserver-client-kubelet": issues client certificates
        that kubelets use to authenticate to kube-apiserver.
          Requests for this signer can be auto-approved by the "csrapproving"
        controller in kube-controller-manager, and can be issued by the "csrsigning"
        controller in kube-controller-manager.
         3. "kubernetes.io/kubelet-serving" issues serving certificates that kubelets
        use to serve TLS endpoints, which kube-apiserver can connect to securely.
          Requests for this signer are never auto-approved by kube-controller-manager,
        and can be issued by the "csrsigning" controller in kube-controller-manager.
        More details are available at
        https://k8s.io/docs/reference/access-authn-authz/certificate-signing-requests/#kubernetes-signers
        Custom signerNames can also be specified. The signer defines:
         1. Trust distribution: how trust (CA bundles) are distributed.
         2. Permitted subjects: and behavior when a disallowed subject is requested.
         3. Required, permitted, or forbidden x509 extensions in the request
        (including whether subjectAltNames are allowed, which types, restrictions on
        allowed values) and behavior when a disallowed extension is requested.
         4. Required, permitted, or forbidden key usages / extended key usages.
         5. Expiration/certificate lifetime: whether it is fixed by the signer,
        configurable by the admin.
         6. Whether or not requests for CA certificates are allowed.
      * **expirationSeconds** ``Optional[int]`` - expirationSeconds is the requested duration of validity of the issued
        certificate. The certificate signer may issue a certificate with a different
        validity duration so a client must check the delta between the notBefore and
        and notAfter fields in the issued certificate to determine the actual
        duration.
        The v1.22+ in-tree implementations of the well-known Kubernetes signers will
        honor this field as long as the requested duration is not greater than the
        maximum duration they will honor per the --cluster-signing-duration CLI flag
        to the Kubernetes controller manager.
        Certificate signers may not honor this field for various reasons:
          1. Old signer that is unaware of the field (such as the in-tree
             implementations prior to v1.22)
          2. Signer whose configured maximum is shorter than the requested duration
          3. Signer whose configured minimum is longer than the requested duration
        The minimum valid value for expirationSeconds is 600, i.e. 10 minutes.
      * **extra** ``Optional[dict]`` - extra contains extra attributes of the user that created the
        CertificateSigningRequest. Populated by the API server on creation and
        immutable.
      * **groups** ``Optional[List[str]]`` - groups contains group membership of the user that created the
        CertificateSigningRequest. Populated by the API server on creation and
        immutable.
      * **uid** ``Optional[str]`` - uid contains the uid of the user that created the CertificateSigningRequest.
        Populated by the API server on creation and immutable.
      * **usages** ``Optional[List[str]]`` - usages specifies a set of key usages requested in the issued certificate.
        Requests for TLS client certificates typically request: "digital signature",
        "key encipherment", "client auth".
        Requests for TLS serving certificates typically request: "key encipherment",
        "digital signature", "server auth".
        Valid values are:
         "signing", "digital signature", "content commitment",
         "key encipherment", "key agreement", "data encipherment",
         "cert sign", "crl sign", "encipher only", "decipher only", "any",
         "server auth", "client auth",
         "code signing", "email protection", "s/mime",
         "ipsec end system", "ipsec tunnel", "ipsec user",
         "timestamping", "ocsp signing", "microsoft sgc", "netscape sgc"
      * **username** ``Optional[str]`` - username contains the name of the user that created the
        CertificateSigningRequest. Populated by the API server on creation and
        immutable.
    """
    request: 'str'
    signerName: 'str'
    expirationSeconds: 'Optional[int]' = None
    extra: 'Optional[dict]' = None
    groups: 'Optional[List[str]]' = None
    uid: 'Optional[str]' = None
    usages: 'Optional[List[str]]' = None
    username: 'Optional[str]' = None


@dataclass
class CertificateSigningRequestStatus(DictMixin):
    r"""CertificateSigningRequestStatus contains conditions used to indicate
      approved/denied/failed status of the request, and the issued certificate.

      **parameters**

      * **certificate** ``Optional[str]`` - certificate is populated with an issued certificate by the signer after an
        Approved condition is present. This field is set via the /status subresource.
        Once populated, this field is immutable.
        If the certificate signing request is denied, a condition of type "Denied" is
        added and this field remains empty. If the signer cannot issue the
        certificate, a condition of type "Failed" is added and this field remains
        empty.
        Validation requirements:
         1. certificate must contain one or more PEM blocks.
         2. All PEM blocks must have the "CERTIFICATE" label, contain no headers, and
        the encoded data
          must be a BER-encoded ASN.1 Certificate structure as described in section 4
        of RFC5280.
         3. Non-PEM content may appear before or after the "CERTIFICATE" PEM blocks
        and is unvalidated,
          to allow for explanatory text as described in section 5.2 of RFC7468.
        If more than one PEM block is present, and the definition of the requested
        spec.signerName does not indicate otherwise, the first block is the issued
        certificate, and subsequent blocks should be treated as intermediate
        certificates and presented in TLS handshakes.
        The certificate is encoded in PEM format.
        When serialized as JSON or YAML, the data is additionally base64-encoded, so
        it consists of:
            base64(
            -----BEGIN CERTIFICATE-----
            ...
            -----END CERTIFICATE-----
            )
      * **conditions** ``Optional[List[CertificateSigningRequestCondition]]`` - conditions applied to the request. Known conditions are "Approved", "Denied",
        and "Failed".
    """
    certificate: 'Optional[str]' = None
    conditions: 'Optional[List[CertificateSigningRequestCondition]]' = None





# autogenerated module
from typing import ClassVar

from ..core import resource as res
from ..models import node_v1beta1 as m_node_v1beta1


class RuntimeClass(res.GlobalResource, m_node_v1beta1.RuntimeClass):
    """* **Extends**: ``models.node_v1beta1.RuntimeClass``
       * **Type**: Global Resource
       * **Accepted client methods**: `delete`, `deletecollection`, `get`, `list`, `patch`, `create`, `replace`, `watch`
    """
    _api_info = res.ApiInfo(
        resource=res.ResourceDef('node.k8s.io', 'v1beta1', 'RuntimeClass'),
        plural='runtimeclasses',
        verbs=['delete', 'deletecollection', 'get', 'list', 'patch', 'post', 'put', 'watch'],
    )




# autogenerated module
from typing import List, Optional, TYPE_CHECKING

from ._schema import dataclass, field, DictMixin

if TYPE_CHECKING:   # Fix for pycharm autocompletion https://youtrack.jetbrains.com/issue/PY-54560
    from dataclasses import dataclass, field

from . import meta_v1


@dataclass
class Lease(DictMixin):
    r"""Lease defines a lease concept.

      **parameters**

      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ObjectMeta]`` - More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
      * **spec** ``Optional[LeaseSpec]`` - Specification of the Lease. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
    """
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ObjectMeta]' = None
    spec: 'Optional[LeaseSpec]' = None


@dataclass
class LeaseList(DictMixin):
    r"""LeaseList is a list of Lease objects.

      **parameters**

      * **items** ``List[Lease]`` - Items is a list of schema objects.
      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ListMeta]`` - Standard list metadata. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
    """
    items: 'List[Lease]'
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ListMeta]' = None


@dataclass
class LeaseSpec(DictMixin):
    r"""LeaseSpec is a specification of a Lease.

      **parameters**

      * **acquireTime** ``Optional[meta_v1.MicroTime]`` - acquireTime is a time when the current lease was acquired.
      * **holderIdentity** ``Optional[str]`` - holderIdentity contains the identity of the holder of a current lease.
      * **leaseDurationSeconds** ``Optional[int]`` - leaseDurationSeconds is a duration that candidates for a lease need to wait to
        force acquire it. This is measure against time of last observed RenewTime.
      * **leaseTransitions** ``Optional[int]`` - leaseTransitions is the number of transitions of a lease between holders.
      * **renewTime** ``Optional[meta_v1.MicroTime]`` - renewTime is a time when the current holder of a lease has last updated the
        lease.
    """
    acquireTime: 'Optional[meta_v1.MicroTime]' = None
    holderIdentity: 'Optional[str]' = None
    leaseDurationSeconds: 'Optional[int]' = None
    leaseTransitions: 'Optional[int]' = None
    renewTime: 'Optional[meta_v1.MicroTime]' = None





# autogenerated module
from typing import List, Optional, TYPE_CHECKING

from ._schema import dataclass, field, DictMixin

if TYPE_CHECKING:   # Fix for pycharm autocompletion https://youtrack.jetbrains.com/issue/PY-54560
    from dataclasses import dataclass, field

from . import core_v1
from . import meta_v1


@dataclass
class Overhead(DictMixin):
    r"""Overhead structure represents the resource overhead associated with running a
      pod.

      **parameters**

      * **podFixed** ``Optional[dict]`` - PodFixed represents the fixed resource overhead associated with running a pod.
    """
    podFixed: 'Optional[dict]' = None


@dataclass
class RuntimeClass(DictMixin):
    r"""RuntimeClass defines a class of container runtime supported in the cluster.
      The RuntimeClass is used to determine which container runtime is used to run
      all containers in a pod. RuntimeClasses are (currently) manually defined by a
      user or cluster provisioner, and referenced in the PodSpec. The Kubelet is
      responsible for resolving the RuntimeClassName reference before running the
      pod.  For more details, see
      https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class

      **parameters**

      * **handler** ``str`` - Handler specifies the underlying runtime and configuration that the CRI
        implementation will use to handle pods of this class. The possible values are
        specific to the node & CRI configuration.  It is assumed that all handlers are
        available on every node, and handlers of the same name are equivalent on every
        node. For example, a handler called "runc" might specify that the runc OCI
        runtime (using native Linux containers) will be used to run the containers in
        a pod. The Handler must be lowercase, conform to the DNS Label (RFC 1123)
        requirements, and is immutable.
      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ObjectMeta]`` - More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
      * **overhead** ``Optional[Overhead]`` - Overhead represents the resource overhead associated with running a pod for a
        given RuntimeClass. For more details, see
        https://git.k8s.io/enhancements/keps/sig-node/688-pod-overhead/README.md
      * **scheduling** ``Optional[Scheduling]`` - Scheduling holds the scheduling constraints to ensure that pods running with
        this RuntimeClass are scheduled to nodes that support it. If scheduling is
        nil, this RuntimeClass is assumed to be supported by all nodes.
    """
    handler: 'str'
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ObjectMeta]' = None
    overhead: 'Optional[Overhead]' = None
    scheduling: 'Optional[Scheduling]' = None


@dataclass
class RuntimeClassList(DictMixin):
    r"""RuntimeClassList is a list of RuntimeClass objects.

      **parameters**

      * **items** ``List[RuntimeClass]`` - Items is a list of schema objects.
      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ListMeta]`` - Standard list metadata. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
    """
    items: 'List[RuntimeClass]'
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ListMeta]' = None


@dataclass
class Scheduling(DictMixin):
    r"""Scheduling specifies the scheduling constraints for nodes supporting a
      RuntimeClass.

      **parameters**

      * **nodeSelector** ``Optional[dict]`` - nodeSelector lists labels that must be present on nodes that support this
        RuntimeClass. Pods using this RuntimeClass can only be scheduled to a node
        matched by this selector. The RuntimeClass nodeSelector is merged with a pod's
        existing nodeSelector. Any conflicts will cause the pod to be rejected in
        admission.
      * **tolerations** ``Optional[List[core_v1.Toleration]]`` - tolerations are appended (excluding duplicates) to pods running with this
        RuntimeClass during admission, effectively unioning the set of nodes tolerated
        by the pod and the RuntimeClass.
    """
    nodeSelector: 'Optional[dict]' = None
    tolerations: 'Optional[List[core_v1.Toleration]]' = None





# autogenerated module
from typing import List, Optional, TYPE_CHECKING

from ._schema import dataclass, field, DictMixin

if TYPE_CHECKING:   # Fix for pycharm autocompletion https://youtrack.jetbrains.com/issue/PY-54560
    from dataclasses import dataclass, field

from . import core_v1
from . import meta_v1
from . import util_intstr


@dataclass
class AllowedCSIDriver(DictMixin):
    r"""AllowedCSIDriver represents a single inline CSI Driver that is allowed to be
      used.

      **parameters**

      * **name** ``str`` - Name is the registered name of the CSI driver
    """
    name: 'str'


@dataclass
class AllowedFlexVolume(DictMixin):
    r"""AllowedFlexVolume represents a single Flexvolume that is allowed to be used.

      **parameters**

      * **driver** ``str`` - driver is the name of the Flexvolume driver.
    """
    driver: 'str'


@dataclass
class AllowedHostPath(DictMixin):
    r"""AllowedHostPath defines the host volume conditions that will be enabled by a
      policy for pods to use. It requires the path prefix to be defined.

      **parameters**

      * **pathPrefix** ``Optional[str]`` - pathPrefix is the path prefix that the host volume must match. It does not
        support `*`. Trailing slashes are trimmed when validating the path prefix with
        a host path.
        Examples: `/foo` would allow `/foo`, `/foo/` and `/foo/bar` `/foo` would not
        allow `/food` or `/etc/foo`
      * **readOnly** ``Optional[bool]`` - when set to true, will allow host volumes matching the pathPrefix only if all
        volume mounts are readOnly.
    """
    pathPrefix: 'Optional[str]' = None
    readOnly: 'Optional[bool]' = None


@dataclass
class FSGroupStrategyOptions(DictMixin):
    r"""FSGroupStrategyOptions defines the strategy type and options used to create
      the strategy.

      **parameters**

      * **ranges** ``Optional[List[IDRange]]`` - ranges are the allowed ranges of fs groups.  If you would like to force a
        single fs group then supply a single range with the same start and end.
        Required for MustRunAs.
      * **rule** ``Optional[str]`` - rule is the strategy that will dictate what FSGroup is used in the
        SecurityContext.
    """
    ranges: 'Optional[List[IDRange]]' = None
    rule: 'Optional[str]' = None


@dataclass
class HostPortRange(DictMixin):
    r"""HostPortRange defines a range of host ports that will be enabled by a policy
      for pods to use.  It requires both the start and end to be defined.

      **parameters**

      * **max** ``int`` - max is the end of the range, inclusive.
      * **min** ``int`` - min is the start of the range, inclusive.
    """
    max: 'int'
    min: 'int'


@dataclass
class IDRange(DictMixin):
    r"""IDRange provides a min/max of an allowed range of IDs.

      **parameters**

      * **max** ``int`` - max is the end of the range, inclusive.
      * **min** ``int`` - min is the start of the range, inclusive.
    """
    max: 'int'
    min: 'int'


@dataclass
class PodDisruptionBudget(DictMixin):
    r"""PodDisruptionBudget is an object to define the max disruption that can be
      caused to a collection of pods

      **parameters**

      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ObjectMeta]`` - Standard object's metadata. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
      * **spec** ``Optional[PodDisruptionBudgetSpec]`` - Specification of the desired behavior of the PodDisruptionBudget.
      * **status** ``Optional[PodDisruptionBudgetStatus]`` - Most recently observed status of the PodDisruptionBudget.
    """
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ObjectMeta]' = None
    spec: 'Optional[PodDisruptionBudgetSpec]' = None
    status: 'Optional[PodDisruptionBudgetStatus]' = None


@dataclass
class PodDisruptionBudgetList(DictMixin):
    r"""PodDisruptionBudgetList is a collection of PodDisruptionBudgets.

      **parameters**

      * **items** ``List[PodDisruptionBudget]`` - items list individual PodDisruptionBudget objects
      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ListMeta]`` - Standard object's metadata. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
    """
    items: 'List[PodDisruptionBudget]'
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ListMeta]' = None


@dataclass
class PodDisruptionBudgetSpec(DictMixin):
    r"""PodDisruptionBudgetSpec is a description of a PodDisruptionBudget.

      **parameters**

      * **maxUnavailable** ``Optional[util_intstr.IntOrString]`` - An eviction is allowed if at most "maxUnavailable" pods selected by "selector"
        are unavailable after the eviction, i.e. even in absence of the evicted pod.
        For example, one can prevent all voluntary evictions by specifying 0. This is
        a mutually exclusive setting with "minAvailable".
      * **minAvailable** ``Optional[util_intstr.IntOrString]`` - An eviction is allowed if at least "minAvailable" pods selected by "selector"
        will still be available after the eviction, i.e. even in the absence of the
        evicted pod.  So for example you can prevent all voluntary evictions by
        specifying "100%".
      * **selector** ``Optional[meta_v1.LabelSelector]`` - Label query over pods whose evictions are managed by the disruption budget. A
        null selector selects no pods. An empty selector ({}) also selects no pods,
        which differs from standard behavior of selecting all pods. In policy/v1, an
        empty selector will select all pods in the namespace.
    """
    maxUnavailable: 'Optional[util_intstr.IntOrString]' = None
    minAvailable: 'Optional[util_intstr.IntOrString]' = None
    selector: 'Optional[meta_v1.LabelSelector]' = None


@dataclass
class PodDisruptionBudgetStatus(DictMixin):
    r"""PodDisruptionBudgetStatus represents information about the status of a
      PodDisruptionBudget. Status may trail the actual state of a system.

      **parameters**

      * **currentHealthy** ``int`` - current number of healthy pods
      * **desiredHealthy** ``int`` - minimum desired number of healthy pods
      * **disruptionsAllowed** ``int`` - Number of pod disruptions that are currently allowed.
      * **expectedPods** ``int`` - total number of pods counted by this disruption budget
      * **conditions** ``Optional[List[meta_v1.Condition]]`` - Conditions contain conditions for PDB. The disruption controller sets the
        DisruptionAllowed condition. The following are known values for the reason
        field (additional reasons could be added in the future): - SyncFailed: The
        controller encountered an error and wasn't able to compute
                      the number of allowed disruptions. Therefore no disruptions are
                      allowed and the status of the condition will be False.
        - InsufficientPods: The number of pods are either at or below the number
                            required by the PodDisruptionBudget. No disruptions are
                            allowed and the status of the condition will be False.
        - SufficientPods: There are more pods than required by the
        PodDisruptionBudget.
                          The condition will be True, and the number of allowed
                          disruptions are provided by the disruptionsAllowed property.
      * **disruptedPods** ``Optional[dict]`` - DisruptedPods contains information about pods whose eviction was processed by
        the API server eviction subresource handler but has not yet been observed by
        the PodDisruptionBudget controller. A pod will be in this map from the time
        when the API server processed the eviction request to the time when the pod is
        seen by PDB controller as having been marked for deletion (or after a
        timeout). The key in the map is the name of the pod and the value is the time
        when the API server processed the eviction request. If the deletion didn't
        occur and a pod is still there it will be removed from the list automatically
        by PodDisruptionBudget controller after some time. If everything goes smooth
        this map should be empty for the most of the time. Large number of entries in
        the map may indicate problems with pod deletions.
      * **observedGeneration** ``Optional[int]`` - Most recent generation observed when updating this PDB status.
        DisruptionsAllowed and other status information is valid only if
        observedGeneration equals to PDB's object generation.
    """
    currentHealthy: 'int'
    desiredHealthy: 'int'
    disruptionsAllowed: 'int'
    expectedPods: 'int'
    conditions: 'Optional[List[meta_v1.Condition]]' = None
    disruptedPods: 'Optional[dict]' = None
    observedGeneration: 'Optional[int]' = None


@dataclass
class PodSecurityPolicy(DictMixin):
    r"""PodSecurityPolicy governs the ability to make requests that affect the
      Security Context that will be applied to a pod and container. Deprecated in
      1.21.

      **parameters**

      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ObjectMeta]`` - Standard object's metadata. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
      * **spec** ``Optional[PodSecurityPolicySpec]`` - spec defines the policy enforced.
    """
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ObjectMeta]' = None
    spec: 'Optional[PodSecurityPolicySpec]' = None


@dataclass
class PodSecurityPolicyList(DictMixin):
    r"""PodSecurityPolicyList is a list of PodSecurityPolicy objects.

      **parameters**

      * **items** ``List[PodSecurityPolicy]`` - items is a list of schema objects.
      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ListMeta]`` - Standard list metadata. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
    """
    items: 'List[PodSecurityPolicy]'
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ListMeta]' = None


@dataclass
class PodSecurityPolicySpec(DictMixin):
    r"""PodSecurityPolicySpec defines the policy enforced.

      **parameters**

      * **fsGroup** ``FSGroupStrategyOptions`` - fsGroup is the strategy that will dictate what fs group is used by the
        SecurityContext.
      * **runAsUser** ``RunAsUserStrategyOptions`` - runAsUser is the strategy that will dictate the allowable RunAsUser values
        that may be set.
      * **seLinux** ``SELinuxStrategyOptions`` - seLinux is the strategy that will dictate the allowable labels that may be
        set.
      * **supplementalGroups** ``SupplementalGroupsStrategyOptions`` - supplementalGroups is the strategy that will dictate what supplemental groups
        are used by the SecurityContext.
      * **allowPrivilegeEscalation** ``Optional[bool]`` - allowPrivilegeEscalation determines if a pod can request to allow privilege
        escalation. If unspecified, defaults to true.
      * **allowedCSIDrivers** ``Optional[List[AllowedCSIDriver]]`` - AllowedCSIDrivers is an allowlist of inline CSI drivers that must be
        explicitly set to be embedded within a pod spec. An empty value indicates that
        any CSI driver can be used for inline ephemeral volumes. This is a beta field,
        and is only honored if the API server enables the CSIInlineVolume feature
        gate.
      * **allowedCapabilities** ``Optional[List[str]]`` - allowedCapabilities is a list of capabilities that can be requested to add to
        the container. Capabilities in this field may be added at the pod author's
        discretion. You must not list a capability in both allowedCapabilities and
        requiredDropCapabilities.
      * **allowedFlexVolumes** ``Optional[List[AllowedFlexVolume]]`` - allowedFlexVolumes is an allowlist of Flexvolumes.  Empty or nil indicates
        that all Flexvolumes may be used.  This parameter is effective only when the
        usage of the Flexvolumes is allowed in the "volumes" field.
      * **allowedHostPaths** ``Optional[List[AllowedHostPath]]`` - allowedHostPaths is an allowlist of host paths. Empty indicates that all host
        paths may be used.
      * **allowedProcMountTypes** ``Optional[List[str]]`` - AllowedProcMountTypes is an allowlist of allowed ProcMountTypes. Empty or nil
        indicates that only the DefaultProcMountType may be used. This requires the
        ProcMountType feature flag to be enabled.
      * **allowedUnsafeSysctls** ``Optional[List[str]]`` - allowedUnsafeSysctls is a list of explicitly allowed unsafe sysctls, defaults
        to none. Each entry is either a plain sysctl name or ends in "*" in which case
        it is considered as a prefix of allowed sysctls. Single * means all unsafe
        sysctls are allowed. Kubelet has to allowlist all allowed unsafe sysctls
        explicitly to avoid rejection.
        Examples: e.g. "foo/*" allows "foo/bar", "foo/baz", etc. e.g. "foo.*" allows
        "foo.bar", "foo.baz", etc.
      * **defaultAddCapabilities** ``Optional[List[str]]`` - defaultAddCapabilities is the default set of capabilities that will be added
        to the container unless the pod spec specifically drops the capability.  You
        may not list a capability in both defaultAddCapabilities and
        requiredDropCapabilities. Capabilities added here are implicitly allowed, and
        need not be included in the allowedCapabilities list.
      * **defaultAllowPrivilegeEscalation** ``Optional[bool]`` - defaultAllowPrivilegeEscalation controls the default setting for whether a
        process can gain more privileges than its parent process.
      * **forbiddenSysctls** ``Optional[List[str]]`` - forbiddenSysctls is a list of explicitly forbidden sysctls, defaults to none.
        Each entry is either a plain sysctl name or ends in "*" in which case it is
        considered as a prefix of forbidden sysctls. Single * means all sysctls are
        forbidden.
        Examples: e.g. "foo/*" forbids "foo/bar", "foo/baz", etc. e.g. "foo.*" forbids
        "foo.bar", "foo.baz", etc.
      * **hostIPC** ``Optional[bool]`` - hostIPC determines if the policy allows the use of HostIPC in the pod spec.
      * **hostNetwork** ``Optional[bool]`` - hostNetwork determines if the policy allows the use of HostNetwork in the pod
        spec.
      * **hostPID** ``Optional[bool]`` - hostPID determines if the policy allows the use of HostPID in the pod spec.
      * **hostPorts** ``Optional[List[HostPortRange]]`` - hostPorts determines which host port ranges are allowed to be exposed.
      * **privileged** ``Optional[bool]`` - privileged determines if a pod can request to be run as privileged.
      * **readOnlyRootFilesystem** ``Optional[bool]`` - readOnlyRootFilesystem when set to true will force containers to run with a
        read only root file system.  If the container specifically requests to run
        with a non-read only root file system the PSP should deny the pod. If set to
        false the container may run with a read only root file system if it wishes but
        it will not be forced to.
      * **requiredDropCapabilities** ``Optional[List[str]]`` - requiredDropCapabilities are the capabilities that will be dropped from the
        container.  These are required to be dropped and cannot be added.
      * **runAsGroup** ``Optional[RunAsGroupStrategyOptions]`` - RunAsGroup is the strategy that will dictate the allowable RunAsGroup values
        that may be set. If this field is omitted, the pod's RunAsGroup can take any
        value. This field requires the RunAsGroup feature gate to be enabled.
      * **runtimeClass** ``Optional[RuntimeClassStrategyOptions]`` - runtimeClass is the strategy that will dictate the allowable RuntimeClasses
        for a pod. If this field is omitted, the pod's runtimeClassName field is
        unrestricted. Enforcement of this field depends on the RuntimeClass feature
        gate being enabled.
      * **volumes** ``Optional[List[str]]`` - volumes is an allowlist of volume plugins. Empty indicates that no volumes may
        be used. To allow all volumes you may use '*'.
    """
    fsGroup: 'FSGroupStrategyOptions'
    runAsUser: 'RunAsUserStrategyOptions'
    seLinux: 'SELinuxStrategyOptions'
    supplementalGroups: 'SupplementalGroupsStrategyOptions'
    allowPrivilegeEscalation: 'Optional[bool]' = None
    allowedCSIDrivers: 'Optional[List[AllowedCSIDriver]]' = None
    allowedCapabilities: 'Optional[List[str]]' = None
    allowedFlexVolumes: 'Optional[List[AllowedFlexVolume]]' = None
    allowedHostPaths: 'Optional[List[AllowedHostPath]]' = None
    allowedProcMountTypes: 'Optional[List[str]]' = None
    allowedUnsafeSysctls: 'Optional[List[str]]' = None
    defaultAddCapabilities: 'Optional[List[str]]' = None
    defaultAllowPrivilegeEscalation: 'Optional[bool]' = None
    forbiddenSysctls: 'Optional[List[str]]' = None
    hostIPC: 'Optional[bool]' = None
    hostNetwork: 'Optional[bool]' = None
    hostPID: 'Optional[bool]' = None
    hostPorts: 'Optional[List[HostPortRange]]' = None
    privileged: 'Optional[bool]' = None
    readOnlyRootFilesystem: 'Optional[bool]' = None
    requiredDropCapabilities: 'Optional[List[str]]' = None
    runAsGroup: 'Optional[RunAsGroupStrategyOptions]' = None
    runtimeClass: 'Optional[RuntimeClassStrategyOptions]' = None
    volumes: 'Optional[List[str]]' = None


@dataclass
class RunAsGroupStrategyOptions(DictMixin):
    r"""RunAsGroupStrategyOptions defines the strategy type and any options used to
      create the strategy.

      **parameters**

      * **rule** ``str`` - rule is the strategy that will dictate the allowable RunAsGroup values that
        may be set.
      * **ranges** ``Optional[List[IDRange]]`` - ranges are the allowed ranges of gids that may be used. If you would like to
        force a single gid then supply a single range with the same start and end.
        Required for MustRunAs.
    """
    rule: 'str'
    ranges: 'Optional[List[IDRange]]' = None


@dataclass
class RunAsUserStrategyOptions(DictMixin):
    r"""RunAsUserStrategyOptions defines the strategy type and any options used to
      create the strategy.

      **parameters**

      * **rule** ``str`` - rule is the strategy that will dictate the allowable RunAsUser values that may
        be set.
      * **ranges** ``Optional[List[IDRange]]`` - ranges are the allowed ranges of uids that may be used. If you would like to
        force a single uid then supply a single range with the same start and end.
        Required for MustRunAs.
    """
    rule: 'str'
    ranges: 'Optional[List[IDRange]]' = None


@dataclass
class RuntimeClassStrategyOptions(DictMixin):
    r"""RuntimeClassStrategyOptions define the strategy that will dictate the
      allowable RuntimeClasses for a pod.

      **parameters**

      * **allowedRuntimeClassNames** ``List[str]`` - allowedRuntimeClassNames is an allowlist of RuntimeClass names that may be
        specified on a pod. A value of "*" means that any RuntimeClass name is
        allowed, and must be the only item in the list. An empty list requires the
        RuntimeClassName field to be unset.
      * **defaultRuntimeClassName** ``Optional[str]`` - defaultRuntimeClassName is the default RuntimeClassName to set on the pod. The
        default MUST be allowed by the allowedRuntimeClassNames list. A value of nil
        does not mutate the Pod.
    """
    allowedRuntimeClassNames: 'List[str]'
    defaultRuntimeClassName: 'Optional[str]' = None


@dataclass
class SELinuxStrategyOptions(DictMixin):
    r"""SELinuxStrategyOptions defines the strategy type and any options used to
      create the strategy.

      **parameters**

      * **rule** ``str`` - rule is the strategy that will dictate the allowable labels that may be set.
      * **seLinuxOptions** ``Optional[core_v1.SELinuxOptions]`` - seLinuxOptions required to run as; required for MustRunAs More info:
        https://kubernetes.io/docs/tasks/configure-pod-container/security-context/
    """
    rule: 'str'
    seLinuxOptions: 'Optional[core_v1.SELinuxOptions]' = None


@dataclass
class SupplementalGroupsStrategyOptions(DictMixin):
    r"""SupplementalGroupsStrategyOptions defines the strategy type and options used
      to create the strategy.

      **parameters**

      * **ranges** ``Optional[List[IDRange]]`` - ranges are the allowed ranges of supplemental groups.  If you would like to
        force a single supplemental group then supply a single range with the same
        start and end. Required for MustRunAs.
      * **rule** ``Optional[str]`` - rule is the strategy that will dictate what supplemental groups is used in the
        SecurityContext.
    """
    ranges: 'Optional[List[IDRange]]' = None
    rule: 'Optional[str]' = None





# autogenerated module
from typing import List, Optional, TYPE_CHECKING

from ._schema import dataclass, field, DictMixin

if TYPE_CHECKING:   # Fix for pycharm autocompletion https://youtrack.jetbrains.com/issue/PY-54560
    from dataclasses import dataclass, field

from . import core_v1
from . import meta_v1


@dataclass
class CronJob(DictMixin):
    r"""CronJob represents the configuration of a single cron job.

      **parameters**

      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ObjectMeta]`` - Standard object's metadata. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
      * **spec** ``Optional[CronJobSpec]`` - Specification of the desired behavior of a cron job, including the schedule.
        More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
      * **status** ``Optional[CronJobStatus]`` - Current status of a cron job. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
    """
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ObjectMeta]' = None
    spec: 'Optional[CronJobSpec]' = None
    status: 'Optional[CronJobStatus]' = None


@dataclass
class CronJobList(DictMixin):
    r"""CronJobList is a collection of cron jobs.

      **parameters**

      * **items** ``List[CronJob]`` - items is the list of CronJobs.
      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ListMeta]`` - Standard list metadata. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
    """
    items: 'List[CronJob]'
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ListMeta]' = None


@dataclass
class CronJobSpec(DictMixin):
    r"""CronJobSpec describes how the job execution will look like and when it will
      actually run.

      **parameters**

      * **jobTemplate** ``JobTemplateSpec`` - Specifies the job that will be created when executing a CronJob.
      * **schedule** ``str`` - The schedule in Cron format, see https://en.wikipedia.org/wiki/Cron.
      * **concurrencyPolicy** ``Optional[str]`` - Specifies how to treat concurrent executions of a Job. Valid values are: -
        "Allow" (default): allows CronJobs to run concurrently; - "Forbid": forbids
        concurrent runs, skipping next run if previous run hasn't finished yet; -
        "Replace": cancels currently running job and replaces it with a new one
      * **failedJobsHistoryLimit** ``Optional[int]`` - The number of failed finished jobs to retain. Value must be non-negative
        integer. Defaults to 1.
      * **startingDeadlineSeconds** ``Optional[int]`` - Optional deadline in seconds for starting the job if it misses scheduled time
        for any reason.  Missed jobs executions will be counted as failed ones.
      * **successfulJobsHistoryLimit** ``Optional[int]`` - The number of successful finished jobs to retain. Value must be non-negative
        integer. Defaults to 3.
      * **suspend** ``Optional[bool]`` - This flag tells the controller to suspend subsequent executions, it does not
        apply to already started executions.  Defaults to false.
      * **timeZone** ``Optional[str]`` - The time zone for the given schedule, see
        https://en.wikipedia.org/wiki/List_of_tz_database_time_zones. If not
        specified, this will rely on the time zone of the kube-controller-manager
        process. ALPHA: This field is in alpha and must be enabled via the
        `CronJobTimeZone` feature gate.
    """
    jobTemplate: 'JobTemplateSpec'
    schedule: 'str'
    concurrencyPolicy: 'Optional[str]' = None
    failedJobsHistoryLimit: 'Optional[int]' = None
    startingDeadlineSeconds: 'Optional[int]' = None
    successfulJobsHistoryLimit: 'Optional[int]' = None
    suspend: 'Optional[bool]' = None
    timeZone: 'Optional[str]' = None


@dataclass
class CronJobStatus(DictMixin):
    r"""CronJobStatus represents the current state of a cron job.

      **parameters**

      * **active** ``Optional[List[core_v1.ObjectReference]]`` - A list of pointers to currently running jobs.
      * **lastScheduleTime** ``Optional[meta_v1.Time]`` - Information when was the last time the job was successfully scheduled.
      * **lastSuccessfulTime** ``Optional[meta_v1.Time]`` - Information when was the last time the job successfully completed.
    """
    active: 'Optional[List[core_v1.ObjectReference]]' = None
    lastScheduleTime: 'Optional[meta_v1.Time]' = None
    lastSuccessfulTime: 'Optional[meta_v1.Time]' = None


@dataclass
class Job(DictMixin):
    r"""Job represents the configuration of a single job.

      **parameters**

      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ObjectMeta]`` - Standard object's metadata. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
      * **spec** ``Optional[JobSpec]`` - Specification of the desired behavior of a job. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
      * **status** ``Optional[JobStatus]`` - Current status of a job. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
    """
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ObjectMeta]' = None
    spec: 'Optional[JobSpec]' = None
    status: 'Optional[JobStatus]' = None


@dataclass
class JobCondition(DictMixin):
    r"""JobCondition describes current state of a job.

      **parameters**

      * **status** ``str`` - Status of the condition, one of True, False, Unknown.
      * **type** ``str`` - Type of job condition, Complete or Failed.
      * **lastProbeTime** ``Optional[meta_v1.Time]`` - Last time the condition was checked.
      * **lastTransitionTime** ``Optional[meta_v1.Time]`` - Last time the condition transit from one status to another.
      * **message** ``Optional[str]`` - Human readable message indicating details about last transition.
      * **reason** ``Optional[str]`` - (brief) reason for the condition's last transition.
    """
    status: 'str'
    type: 'str'
    lastProbeTime: 'Optional[meta_v1.Time]' = None
    lastTransitionTime: 'Optional[meta_v1.Time]' = None
    message: 'Optional[str]' = None
    reason: 'Optional[str]' = None


@dataclass
class JobList(DictMixin):
    r"""JobList is a collection of jobs.

      **parameters**

      * **items** ``List[Job]`` - items is the list of Jobs.
      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ListMeta]`` - Standard list metadata. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
    """
    items: 'List[Job]'
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ListMeta]' = None


@dataclass
class JobSpec(DictMixin):
    r"""JobSpec describes how the job execution will look like.

      **parameters**

      * **template** ``core_v1.PodTemplateSpec`` - Describes the pod that will be created when executing a job. More info:
        https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/
      * **activeDeadlineSeconds** ``Optional[int]`` - Specifies the duration in seconds relative to the startTime that the job may
        be continuously active before the system tries to terminate it; value must be
        positive integer. If a Job is suspended (at creation or through an update),
        this timer will effectively be stopped and reset when the Job is resumed
        again.
      * **backoffLimit** ``Optional[int]`` - Specifies the number of retries before marking this job failed. Defaults to 6
      * **completionMode** ``Optional[str]`` - CompletionMode specifies how Pod completions are tracked. It can be
        `NonIndexed` (default) or `Indexed`.
        `NonIndexed` means that the Job is considered complete when there have been
        .spec.completions successfully completed Pods. Each Pod completion is
        homologous to each other.
        `Indexed` means that the Pods of a Job get an associated completion index from
        0 to (.spec.completions - 1), available in the annotation
        batch.kubernetes.io/job-completion-index. The Job is considered complete when
        there is one successfully completed Pod for each index. When value is
        `Indexed`, .spec.completions must be specified and `.spec.parallelism` must be
        less than or equal to 10^5. In addition, The Pod name takes the form
        `$(job-name)-$(index)-$(random-string)`, the Pod hostname takes the form
        `$(job-name)-$(index)`.
        More completion modes can be added in the future. If the Job controller
        observes a mode that it doesn't recognize, which is possible during upgrades
        due to version skew, the controller skips updates for the Job.
      * **completions** ``Optional[int]`` - Specifies the desired number of successfully finished pods the job should be
        run with.  Setting to nil means that the success of any pod signals the
        success of all pods, and allows parallelism to have any positive value.
        Setting to 1 means that parallelism is limited to 1 and the success of that
        pod signals the success of the job. More info:
        https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/
      * **manualSelector** ``Optional[bool]`` - manualSelector controls generation of pod labels and pod selectors. Leave
        `manualSelector` unset unless you are certain what you are doing. When false
        or unset, the system pick labels unique to this job and appends those labels
        to the pod template.  When true, the user is responsible for picking unique
        labels and specifying the selector.  Failure to pick a unique label may cause
        this and other jobs to not function correctly.  However, You may see
        `manualSelector=true` in jobs that were created with the old
        `extensions/v1beta1` API. More info:
        https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/#specifying-your-own-pod-selector
      * **parallelism** ``Optional[int]`` - Specifies the maximum desired number of pods the job should run at any given
        time. The actual number of pods running in steady state will be less than this
        number when ((.spec.completions - .status.successful) < .spec.parallelism),
        i.e. when the work left to do is less than max parallelism. More info:
        https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/
      * **selector** ``Optional[meta_v1.LabelSelector]`` - A label query over pods that should match the pod count. Normally, the system
        sets this field for you. More info:
        https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
      * **suspend** ``Optional[bool]`` - Suspend specifies whether the Job controller should create Pods or not. If a
        Job is created with suspend set to true, no Pods are created by the Job
        controller. If a Job is suspended after creation (i.e. the flag goes from
        false to true), the Job controller will delete all active Pods associated with
        this Job. Users must design their workload to gracefully handle this.
        Suspending a Job will reset the StartTime field of the Job, effectively
        resetting the ActiveDeadlineSeconds timer too. Defaults to false.
      * **ttlSecondsAfterFinished** ``Optional[int]`` - ttlSecondsAfterFinished limits the lifetime of a Job that has finished
        execution (either Complete or Failed). If this field is set,
        ttlSecondsAfterFinished after the Job finishes, it is eligible to be
        automatically deleted. When the Job is being deleted, its lifecycle guarantees
        (e.g. finalizers) will be honored. If this field is unset, the Job won't be
        automatically deleted. If this field is set to zero, the Job becomes eligible
        to be deleted immediately after it finishes.
    """
    template: 'core_v1.PodTemplateSpec'
    activeDeadlineSeconds: 'Optional[int]' = None
    backoffLimit: 'Optional[int]' = None
    completionMode: 'Optional[str]' = None
    completions: 'Optional[int]' = None
    manualSelector: 'Optional[bool]' = None
    parallelism: 'Optional[int]' = None
    selector: 'Optional[meta_v1.LabelSelector]' = None
    suspend: 'Optional[bool]' = None
    ttlSecondsAfterFinished: 'Optional[int]' = None


@dataclass
class JobStatus(DictMixin):
    r"""JobStatus represents the current state of a Job.

      **parameters**

      * **active** ``Optional[int]`` - The number of pending and running pods.
      * **completedIndexes** ``Optional[str]`` - CompletedIndexes holds the completed indexes when .spec.completionMode =
        "Indexed" in a text format. The indexes are represented as decimal integers
        separated by commas. The numbers are listed in increasing order. Three or more
        consecutive numbers are compressed and represented by the first and last
        element of the series, separated by a hyphen. For example, if the completed
        indexes are 1, 3, 4, 5 and 7, they are represented as "1,3-5,7".
      * **completionTime** ``Optional[meta_v1.Time]`` - Represents time when the job was completed. It is not guaranteed to be set in
        happens-before order across separate operations. It is represented in RFC3339
        form and is in UTC. The completion time is only set when the job finishes
        successfully.
      * **conditions** ``Optional[List[JobCondition]]`` - The latest available observations of an object's current state. When a Job
        fails, one of the conditions will have type "Failed" and status true. When a
        Job is suspended, one of the conditions will have type "Suspended" and status
        true; when the Job is resumed, the status of this condition will become false.
        When a Job is completed, one of the conditions will have type "Complete" and
        status true. More info:
        https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/
      * **failed** ``Optional[int]`` - The number of pods which reached phase Failed.
      * **ready** ``Optional[int]`` - The number of pods which have a Ready condition.
        This field is beta-level. The job controller populates the field when the
        feature gate JobReadyPods is enabled (enabled by default).
      * **startTime** ``Optional[meta_v1.Time]`` - Represents time when the job controller started processing a job. When a Job
        is created in the suspended state, this field is not set until the first time
        it is resumed. This field is reset every time a Job is resumed from
        suspension. It is represented in RFC3339 form and is in UTC.
      * **succeeded** ``Optional[int]`` - The number of pods which reached phase Succeeded.
      * **uncountedTerminatedPods** ``Optional[UncountedTerminatedPods]`` - UncountedTerminatedPods holds the UIDs of Pods that have terminated but the
        job controller hasn't yet accounted for in the status counters.
        The job controller creates pods with a finalizer. When a pod terminates
        (succeeded or failed), the controller does three steps to account for it in
        the job status: (1) Add the pod UID to the arrays in this field. (2) Remove
        the pod finalizer. (3) Remove the pod UID from the arrays while increasing the
        corresponding
            counter.
        This field is beta-level. The job controller only makes use of this field when
        the feature gate JobTrackingWithFinalizers is enabled (enabled by default).
        Old jobs might not be tracked using this field, in which case the field
        remains null.
    """
    active: 'Optional[int]' = None
    completedIndexes: 'Optional[str]' = None
    completionTime: 'Optional[meta_v1.Time]' = None
    conditions: 'Optional[List[JobCondition]]' = None
    failed: 'Optional[int]' = None
    ready: 'Optional[int]' = None
    startTime: 'Optional[meta_v1.Time]' = None
    succeeded: 'Optional[int]' = None
    uncountedTerminatedPods: 'Optional[UncountedTerminatedPods]' = None


@dataclass
class JobTemplateSpec(DictMixin):
    r"""JobTemplateSpec describes the data a Job should have when created from a
      template

      **parameters**

      * **metadata** ``Optional[meta_v1.ObjectMeta]`` - Standard object's metadata of the jobs created from this template. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
      * **spec** ``Optional[JobSpec]`` - Specification of the desired behavior of the job. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
    """
    metadata: 'Optional[meta_v1.ObjectMeta]' = None
    spec: 'Optional[JobSpec]' = None


@dataclass
class UncountedTerminatedPods(DictMixin):
    r"""UncountedTerminatedPods holds UIDs of Pods that have terminated but haven't
      been accounted in Job status counters.

      **parameters**

      * **failed** ``Optional[List[str]]`` - Failed holds UIDs of failed Pods.
      * **succeeded** ``Optional[List[str]]`` - Succeeded holds UIDs of succeeded Pods.
    """
    failed: 'Optional[List[str]]' = None
    succeeded: 'Optional[List[str]]' = None





# autogenerated module
from typing import List, Optional, TYPE_CHECKING

from ._schema import dataclass, field, DictMixin

if TYPE_CHECKING:   # Fix for pycharm autocompletion https://youtrack.jetbrains.com/issue/PY-54560
    from dataclasses import dataclass, field

from typing import Union


IntOrString = Union[int, str]





# autogenerated module
from typing import List, Optional, TYPE_CHECKING

from ._schema import dataclass, field, DictMixin

if TYPE_CHECKING:   # Fix for pycharm autocompletion https://youtrack.jetbrains.com/issue/PY-54560
    from dataclasses import dataclass, field

from . import core_v1
from . import meta_v1


@dataclass
class Event(DictMixin):
    r"""Event is a report of an event somewhere in the cluster. It generally denotes
      some state change in the system. Events have a limited retention time and
      triggers and messages may evolve with time.  Event consumers should not rely
      on the timing of an event with a given Reason reflecting a consistent
      underlying trigger, or the continued existence of events with that Reason.
      Events should be treated as informative, best-effort, supplemental data.

      **parameters**

      * **eventTime** ``meta_v1.MicroTime`` - eventTime is the time when this Event was first observed. It is required.
      * **action** ``Optional[str]`` - action is what action was taken/failed regarding to the regarding object. It
        is machine-readable. This field cannot be empty for new Events and it can have
        at most 128 characters.
      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **deprecatedCount** ``Optional[int]`` - deprecatedCount is the deprecated field assuring backward compatibility with
        core.v1 Event type.
      * **deprecatedFirstTimestamp** ``Optional[meta_v1.Time]`` - deprecatedFirstTimestamp is the deprecated field assuring backward
        compatibility with core.v1 Event type.
      * **deprecatedLastTimestamp** ``Optional[meta_v1.Time]`` - deprecatedLastTimestamp is the deprecated field assuring backward
        compatibility with core.v1 Event type.
      * **deprecatedSource** ``Optional[core_v1.EventSource]`` - deprecatedSource is the deprecated field assuring backward compatibility with
        core.v1 Event type.
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ObjectMeta]`` - Standard object's metadata. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
      * **note** ``Optional[str]`` - note is a human-readable description of the status of this operation. Maximal
        length of the note is 1kB, but libraries should be prepared to handle values
        up to 64kB.
      * **reason** ``Optional[str]`` - reason is why the action was taken. It is human-readable. This field cannot be
        empty for new Events and it can have at most 128 characters.
      * **regarding** ``Optional[core_v1.ObjectReference]`` - regarding contains the object this Event is about. In most cases it's an
        Object reporting controller implements, e.g. ReplicaSetController implements
        ReplicaSets and this event is emitted because it acts on some changes in a
        ReplicaSet object.
      * **related** ``Optional[core_v1.ObjectReference]`` - related is the optional secondary object for more complex actions. E.g. when
        regarding object triggers a creation or deletion of related object.
      * **reportingController** ``Optional[str]`` - reportingController is the name of the controller that emitted this Event,
        e.g. `kubernetes.io/kubelet`. This field cannot be empty for new Events.
      * **reportingInstance** ``Optional[str]`` - reportingInstance is the ID of the controller instance, e.g. `kubelet-xyzf`.
        This field cannot be empty for new Events and it can have at most 128
        characters.
      * **series** ``Optional[EventSeries]`` - series is data about the Event series this event represents or nil if it's a
        singleton Event.
      * **type** ``Optional[str]`` - type is the type of this event (Normal, Warning), new types could be added in
        the future. It is machine-readable. This field cannot be empty for new Events.
    """
    eventTime: 'meta_v1.MicroTime'
    action: 'Optional[str]' = None
    apiVersion: 'Optional[str]' = None
    deprecatedCount: 'Optional[int]' = None
    deprecatedFirstTimestamp: 'Optional[meta_v1.Time]' = None
    deprecatedLastTimestamp: 'Optional[meta_v1.Time]' = None
    deprecatedSource: 'Optional[core_v1.EventSource]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ObjectMeta]' = None
    note: 'Optional[str]' = None
    reason: 'Optional[str]' = None
    regarding: 'Optional[core_v1.ObjectReference]' = None
    related: 'Optional[core_v1.ObjectReference]' = None
    reportingController: 'Optional[str]' = None
    reportingInstance: 'Optional[str]' = None
    series: 'Optional[EventSeries]' = None
    type: 'Optional[str]' = None


@dataclass
class EventList(DictMixin):
    r"""EventList is a list of Event objects.

      **parameters**

      * **items** ``List[Event]`` - items is a list of schema objects.
      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ListMeta]`` - Standard list metadata. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
    """
    items: 'List[Event]'
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ListMeta]' = None


@dataclass
class EventSeries(DictMixin):
    r"""EventSeries contain information on series of events, i.e. thing that was/is
      happening continuously for some time. How often to update the EventSeries is
      up to the event reporters. The default event reporter in
      "k8s.io/client-go/tools/events/event_broadcaster.go" shows how this struct is
      updated on heartbeats and can guide customized reporter implementations.

      **parameters**

      * **count** ``int`` - count is the number of occurrences in this series up to the last heartbeat
        time.
      * **lastObservedTime** ``meta_v1.MicroTime`` - lastObservedTime is the time when last Event from the series was seen before
        last heartbeat.
    """
    count: 'int'
    lastObservedTime: 'meta_v1.MicroTime'


